@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AUTOCREATESCRIPTUTIL_H
-#define AUTOCREATESCRIPTUTIL_H
+#pragma once
 
 #include "ksieveui_private_export.h"
 #include <KSieveUi/AbstractRegexpEditorLineEdit>
@@ -42,4 +41,3 @@ KSIEVEUI_TESTS_EXPORT KSieveUi::AbstractMoveImapFolderWidget *createImapFolderWi
 KSIEVEUI_TESTS_EXPORT KSieveUi::AbstractSelectEmailLineEdit *createSelectEmailsWidget();
 }
 }
-#endif // AUTOCREATESCRIPTUTIL_H
