@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -14,12 +14,10 @@ SelectMimeTypeComboBox::SelectMimeTypeComboBox(QWidget *parent)
     : QComboBox(parent)
 {
     initialize();
-    connect(this, QOverload<int>::of(&SelectMimeTypeComboBox::activated), this, &SelectMimeTypeComboBox::valueChanged);
+    connect(this, &SelectMimeTypeComboBox::activated, this, &SelectMimeTypeComboBox::valueChanged);
 }
 
-SelectMimeTypeComboBox::~SelectMimeTypeComboBox()
-{
-}
+SelectMimeTypeComboBox::~SelectMimeTypeComboBox() = default;
 
 void SelectMimeTypeComboBox::initialize()
 {
