@@ -1,20 +1,21 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "sieveconditiondate.h"
-#include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
-#include "widgets/selectdatewidget.h"
+#include "autocreatescripts/commonwidgets/selectmatchtypecombobox.h"
 #include "editor/sieveeditorutil.h"
+#include "widgets/selectdatewidget.h"
 
 #include <KLocalizedString>
+#include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
+#include "libksieve_debug.h"
 #include <QHBoxLayout>
 #include <QLabel>
-#include "libksieve_debug.h"
 
 using namespace KSieveUi;
 
@@ -25,28 +26,29 @@ SieveConditionDate::SieveConditionDate(SieveEditorGraphicalModeWidget *sieveGrap
 
 QWidget *SieveConditionDate::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
-    auto *lay = new QHBoxLayout;
+    auto w = new QWidget(parent);
+    auto lay = new QHBoxLayout;
     lay->setContentsMargins({});
     w->setLayout(lay);
 
-    auto *matchTypeCombo = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
+    auto matchTypeCombo = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     matchTypeCombo->setObjectName(QStringLiteral("matchtype"));
     connect(matchTypeCombo, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionDate::valueChanged);
     lay->addWidget(matchTypeCombo);
 
-    auto *grid = new QGridLayout;
+    auto grid = new QGridLayout;
     grid->setContentsMargins({});
     lay->addLayout(grid);
-    QLabel *lab = new QLabel(i18n("header:"));
+    auto lab = new QLabel(i18n("header:"));
     grid->addWidget(lab, 0, 0);
 
-    auto *header = new QLineEdit;
+    auto header = new QLineEdit;
+    new KPIM::LineEditCatchReturnKey(header, w);
     connect(header, &QLineEdit::textChanged, this, &SieveConditionDate::valueChanged);
     header->setObjectName(QStringLiteral("header"));
     grid->addWidget(header, 0, 1);
 
-    auto *dateWidget = new SelectDateWidget;
+    auto dateWidget = new SelectDateWidget;
     connect(dateWidget, &SelectDateWidget::valueChanged, this, &SieveConditionDate::valueChanged);
     dateWidget->setObjectName(QStringLiteral("datewidget"));
     grid->addWidget(dateWidget, 1, 0, 1, 2);
@@ -67,7 +69,7 @@ QString SieveConditionDate::code(QWidget *w) const
     const QString dateWidgetStr = dateWidget->code();
 
     return AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("date %1 \"%2\" %3").arg(matchTypeStr, headerStr, dateWidgetStr)
-           + AutoCreateScriptUtil::generateConditionComment(comment());
+        + AutoCreateScriptUtil::generateConditionComment(comment());
 }
 
 bool SieveConditionDate::needCheckIfServerHasCapability() const
@@ -99,7 +101,11 @@ void SieveConditionDate::setParamWidgetValue(QXmlStreamReader &element, QWidget
     QString headerStr;
     QString commentStr;
     while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         const QStringRef tagName = element.name();
+#else
+        const QStringView tagName = element.name();
+#endif
         if (tagName == QLatin1String("str")) {
             if (index == 0) {
                 headerStr = element.readElementText();
@@ -113,11 +119,11 @@ void SieveConditionDate::setParamWidgetValue(QXmlStreamReader &element, QWidget
             }
             ++index;
         } else if (tagName == QLatin1String("tag")) {
-            auto *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
+            auto selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
             selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), notCondition), name(), error);
         } else if (tagName == QLatin1String("crlf")) {
             element.skipCurrentElement();
-            //nothing
+            // nothing
         } else if (tagName == QLatin1String("comment")) {
             commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
         } else {
@@ -129,9 +135,9 @@ void SieveConditionDate::setParamWidgetValue(QXmlStreamReader &element, QWidget
         setComment(commentStr);
     }
 
-    auto *dateWidget = w->findChild<SelectDateWidget *>(QStringLiteral("datewidget"));
+    auto dateWidget = w->findChild<SelectDateWidget *>(QStringLiteral("datewidget"));
     dateWidget->setCode(type, value);
-    auto *header = w->findChild<QLineEdit *>(QStringLiteral("header"));
+    auto header = w->findChild<QLineEdit *>(QStringLiteral("header"));
     header->setText(headerStr);
 }
 
