@@ -1,14 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "sieveimapinstance.h"
 using namespace KSieveUi;
-SieveImapInstance::SieveImapInstance()
-{
-}
+SieveImapInstance::SieveImapInstance() = default;
 
 QString SieveImapInstance::name() const
 {
@@ -62,9 +60,6 @@ void SieveImapInstance::setCapabilities(const QStringList &capabilities)
 
 bool SieveImapInstance::operator==(const SieveImapInstance &other) const
 {
-    return (name() == other.name())
-           && (identifier() == other.identifier())
-           && (status() == other.status())
-           && (mimeTypes() == other.mimeTypes())
-           && (capabilities() == other.capabilities());
+    return (name() == other.name()) && (identifier() == other.identifier()) && (status() == other.status()) && (mimeTypes() == other.mimeTypes())
+        && (capabilities() == other.capabilities());
 }
